@@ -30,5 +30,5 @@ namespace ROPTLIB{
 		/*This function randomly generates a point on the manifold.*/
 		virtual void RandInManifold();
 	};
-}; /*end of ROPTLIB namespace*/
+} /*end of ROPTLIB namespace*/
 #endif // end of EUCTVARIABLE_H
