@@ -29,5 +29,5 @@ namespace ROPTLIB{
 		/*This function randomly generates a point on the manifold.*/
 		virtual void RandInManifold();
 	};
-}; /*end of ROPTLIB namespace*/
+} /*end of ROPTLIB namespace*/
 #endif // end of EUCVARIABLE_H
